"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEventSourceMapping = exports.createLambda = void 0;
const aws_lambda_1 = require("@aws-cdk/aws-lambda");
const aws_iam_1 = require("@aws-cdk/aws-iam");
const core_1 = require("@aws-cdk/core");
const path = __importStar(require("path"));
const LogicalName = "SendEmailTransformer";
const createLambda = (stack, host, role, fieldMappings) => {
    // create lambda
    const funcLogicalId = `${LogicalName}LambdaFunction`;
    const lambdaFunc = host.addLambdaFunction(funcLogicalId, // function name
    `functions/${funcLogicalId}.zip`, // function key
    'index.handler', // function handler
    path.join(__dirname, 'assets', 'lambda.zip'), aws_lambda_1.Runtime.NODEJS_14_X, undefined, // layers
    role, // execution role,
    {
        "API_FIELD_DATA_MAP": JSON.stringify(fieldMappings),
    }, // env vars
    undefined, // lambda timeout
    stack);
    role.attachInlinePolicy(new aws_iam_1.Policy(stack, `${LogicalName}CloudWatchLogAccess`, {
        statements: [
            new aws_iam_1.PolicyStatement({
                actions: ['logs:CreateLogGroup', 'logs:CreateLogStream', 'logs:PutLogEvents'],
                effect: aws_iam_1.Effect.ALLOW,
                resources: [
                    core_1.Fn.sub(`arn:aws:logs:\${AWS::Region}:\${AWS::AccountId}:log-group:/aws/lambda/\${funcName}:log-stream:*`, {
                        funcName: lambdaFunc.functionName,
                    }),
                ],
            }),
        ],
    }));
    role.attachInlinePolicy(new aws_iam_1.Policy(stack, `${LogicalName}SESAccess`, {
        statements: [
            new aws_iam_1.PolicyStatement({
                actions: [
                    'ses:SendEmail',
                    'ses:SendRawEmail',
                    'ses:SendTemplatedEmail',
                ],
                effect: aws_iam_1.Effect.ALLOW,
                resources: [
                    core_1.Fn.sub(`arn:aws:ses:\${AWS::Region}:\${AWS::AccountId}:identity/*`, {
                        funcName: lambdaFunc.functionName,
                    }),
                ],
            }),
        ],
    }));
    return lambdaFunc;
};
exports.createLambda = createLambda;
const createEventSourceMapping = (stack, type, target, tableStreamArn) => {
    return new aws_lambda_1.EventSourceMapping(stack, `SendEmail${type}LambdaMapping`, {
        eventSourceArn: tableStreamArn,
        target,
        batchSize: 100,
        maxBatchingWindow: core_1.Duration.seconds(1),
        enabled: true,
        startingPosition: aws_lambda_1.StartingPosition.LATEST,
    });
};
exports.createEventSourceMapping = createEventSourceMapping;
